@@ -23,8 +23,10 @@ import (
 
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapiv1 "github.com/openshift/api/operator/v1"
+
 	"github.com/openshift/cluster-image-registry-operator/defaults"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/envvar"
 	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/util"
 )
@@ -262,32 +264,7 @@ func (d *driver) storageAccountsClient(cfg *Azure) (storage.AccountsClient, erro
 
 // ConfigEnv configures the environment variables that will be used in the
 // image registry deployment.
-func (d *driver) ConfigEnv() (envs []corev1.EnvVar, err error) {
-	envs = append(envs,
-		corev1.EnvVar{Name: "REGISTRY_STORAGE", Value: "azure"},
-		corev1.EnvVar{Name: "REGISTRY_STORAGE_AZURE_CONTAINER", Value: d.Config.Container},
-		corev1.EnvVar{Name: "REGISTRY_STORAGE_AZURE_ACCOUNTNAME", Value: d.Config.AccountName},
-		corev1.EnvVar{
-			Name: "REGISTRY_STORAGE_AZURE_ACCOUNTKEY",
-			ValueFrom: &corev1.EnvVarSource{
-				SecretKeyRef: &corev1.SecretKeySelector{
-					LocalObjectReference: corev1.LocalObjectReference{
-						Name: defaults.ImageRegistryPrivateConfiguration,
-					},
-					Key: "REGISTRY_STORAGE_AZURE_ACCOUNTKEY",
-				},
-			},
-		},
-	)
-	return
-}
-
-func (d *driver) Volumes() ([]corev1.Volume, []corev1.VolumeMount, error) {
-	return nil, nil, nil
-}
-
-// Secrets returns a map of the storage access secrets.
-func (d *driver) Secrets() (map[string]string, error) {
+func (d *driver) ConfigEnv() (envs envvar.List, err error) {
 	cfg, err := GetConfig(d.Listers)
 	if err != nil {
 		return nil, err
@@ -306,9 +283,21 @@ func (d *driver) Secrets() (map[string]string, error) {
 		}
 	}
 
-	return map[string]string{
-		"REGISTRY_STORAGE_AZURE_ACCOUNTKEY": key,
-	}, nil
+	envs = append(envs,
+		envvar.EnvVar{Name: "REGISTRY_STORAGE", Value: "azure"},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_AZURE_CONTAINER", Value: d.Config.Container},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_AZURE_ACCOUNTNAME", Value: d.Config.AccountName},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_AZURE_ACCOUNTKEY", Value: key, Secret: true},
+	)
+	return
+}
+
+func (d *driver) Volumes() ([]corev1.Volume, []corev1.VolumeMount, error) {
+	return nil, nil, nil
+}
+
+func (d *driver) VolumeSecrets() (map[string]string, error) {
+	return nil, nil
 }
 
 // containerExists determines whether or not an azure container exists
@@ -389,10 +378,7 @@ func (d *driver) StorageExists(cr *imageregistryv1.Config) (bool, error) {
 
 // StorageChanged checks if the storage configuration has changed.
 func (d *driver) StorageChanged(cr *imageregistryv1.Config) bool {
-	if !reflect.DeepEqual(cr.Status.Storage.Azure, cr.Spec.Storage.Azure) {
-		return true
-	}
-	return false
+	return !reflect.DeepEqual(cr.Status.Storage.Azure, cr.Spec.Storage.Azure)
 }
 
 // CreateStorage attempts to create a storage account and a storage container.
@@ -543,7 +529,7 @@ func (d *driver) CreateStorage(cr *imageregistryv1.Config) error {
 
 // RemoveStorage deletes the storage medium that was created.
 func (d *driver) RemoveStorage(cr *imageregistryv1.Config) (retry bool, err error) {
-	if cr.Status.StorageManaged != true {
+	if !cr.Status.StorageManaged {
 		return false, nil
 	}
 	if d.Config.AccountName == "" {
