@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"net/http"
 	"reflect"
+	"strconv"
 	"strings"
 
 	"github.com/gophercloud/gophercloud"
@@ -20,8 +21,10 @@ import (
 
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapi "github.com/openshift/api/operator/v1"
+
 	"github.com/openshift/cluster-image-registry-operator/defaults"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/envvar"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/util"
 )
 
@@ -52,6 +55,38 @@ func replaceEmpty(a string, b string) string {
 	return a
 }
 
+// IsSwiftEnabled checks if Swift service is available for OpenStack platform
+func IsSwiftEnabled(listers *regopclient.Listers) (bool, error) {
+	driver := NewDriver(&imageregistryv1.ImageRegistryConfigStorageSwift{}, listers)
+	conn, err := driver.getSwiftClient()
+	if err != nil {
+		// ErrEndpointNotFound means that Swift is not available
+		if _, ok := err.(*gophercloud.ErrEndpointNotFound); ok {
+			return false, nil
+		}
+		return false, err
+	}
+
+	// Try to list containers to make sure the user has required permissions to do that
+	listOpts := containers.ListOpts{Full: false}
+	_, err = containers.List(conn, listOpts).AllPages()
+	if err != nil {
+		// If the user has no permissions, we consider that Swift is unavailable
+		// Depending on the configuration swift returns different error codes:
+		// 403 with Keystone and 401 with internal Swauth.
+		// It means we have to catch them both.
+		// More information about Swith auth: https://docs.openstack.org/swift/latest/overview_auth.html
+		if _, ok := err.(gophercloud.ErrDefault403); ok {
+			return false, nil
+		}
+		if _, ok := err.(gophercloud.ErrDefault401); ok {
+			return false, nil
+		}
+		return false, err
+	}
+	return true, nil
+}
+
 // GetConfig reads credentials
 func GetConfig(listers *regopclient.Listers) (*Swift, error) {
 	cfg := &Swift{}
@@ -137,7 +172,7 @@ func getCloudProviderCert(listers *regopclient.Listers) (string, error) {
 }
 
 // getSwiftClient returns a client that allows to interact with the OpenStack Swift service
-func (d *driver) getSwiftClient(cr *imageregistryv1.Config) (*gophercloud.ServiceClient, error) {
+func (d *driver) getSwiftClient() (*gophercloud.ServiceClient, error) {
 	cfg, err := GetConfig(d.Listers)
 	if err != nil {
 		return nil, err
@@ -223,20 +258,7 @@ func NewDriver(c *imageregistryv1.ImageRegistryConfigStorageSwift, listers *rego
 	}
 }
 
-// Secrets returns a map of the storage access secrets
-func (d *driver) Secrets() (map[string]string, error) {
-	cfg, err := GetConfig(d.Listers)
-	if err != nil {
-		return nil, err
-	}
-
-	return map[string]string{
-		"REGISTRY_STORAGE_SWIFT_USERNAME": cfg.Username,
-		"REGISTRY_STORAGE_SWIFT_PASSWORD": cfg.Password,
-	}, nil
-}
-
-func (d *driver) ConfigEnv() (envs []corev1.EnvVar, err error) {
+func (d *driver) ConfigEnv() (envs envvar.List, err error) {
 	cfg, err := GetConfig(d.Listers)
 	if err != nil {
 		return nil, err
@@ -251,53 +273,38 @@ func (d *driver) ConfigEnv() (envs []corev1.EnvVar, err error) {
 	d.Config.AuthVersion = replaceEmpty(d.Config.AuthVersion, cfg.IdentityAPIVersion)
 	d.Config.AuthVersion = replaceEmpty(d.Config.AuthVersion, "3")
 
+	authVersion, err := strconv.Atoi(d.Config.AuthVersion)
+	if err != nil {
+		return nil, fmt.Errorf("unable to parse authVersion: %s", err)
+	}
+
 	err = d.ensureAuthURLHasAPIVersion()
 	if err != nil {
 		return nil, err
 	}
 
 	envs = append(envs,
-		corev1.EnvVar{Name: "REGISTRY_STORAGE", Value: "swift"},
-		corev1.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_CONTAINER", Value: d.Config.Container},
-		corev1.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_AUTHURL", Value: d.Config.AuthURL},
-		corev1.EnvVar{
-			Name: "REGISTRY_STORAGE_SWIFT_USERNAME",
-			ValueFrom: &corev1.EnvVarSource{
-				SecretKeyRef: &corev1.SecretKeySelector{
-					LocalObjectReference: corev1.LocalObjectReference{
-						Name: defaults.ImageRegistryPrivateConfiguration,
-					},
-					Key: "REGISTRY_STORAGE_SWIFT_USERNAME",
-				},
-			},
-		},
-		corev1.EnvVar{
-			Name: "REGISTRY_STORAGE_SWIFT_PASSWORD",
-			ValueFrom: &corev1.EnvVarSource{
-				SecretKeyRef: &corev1.SecretKeySelector{
-					LocalObjectReference: corev1.LocalObjectReference{
-						Name: defaults.ImageRegistryPrivateConfiguration,
-					},
-					Key: "REGISTRY_STORAGE_SWIFT_PASSWORD",
-				},
-			},
-		},
-		corev1.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_AUTHVERSION", Value: d.Config.AuthVersion},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE", Value: "swift"},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_CONTAINER", Value: d.Config.Container},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_AUTHURL", Value: d.Config.AuthURL},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_USERNAME", Value: cfg.Username, Secret: true},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_PASSWORD", Value: cfg.Password, Secret: true},
+		envvar.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_AUTHVERSION", Value: authVersion},
 	)
 	if d.Config.Domain != "" {
-		envs = append(envs, corev1.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_DOMAIN", Value: d.Config.Domain})
+		envs = append(envs, envvar.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_DOMAIN", Value: d.Config.Domain})
 	}
 	if d.Config.DomainID != "" {
-		envs = append(envs, corev1.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_DOMAINID", Value: d.Config.DomainID})
+		envs = append(envs, envvar.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_DOMAINID", Value: d.Config.DomainID})
 	}
 	if d.Config.Tenant != "" {
-		envs = append(envs, corev1.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_TENANT", Value: d.Config.Tenant})
+		envs = append(envs, envvar.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_TENANT", Value: d.Config.Tenant})
 	}
 	if d.Config.TenantID != "" {
-		envs = append(envs, corev1.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_TENANTID", Value: d.Config.TenantID})
+		envs = append(envs, envvar.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_TENANTID", Value: d.Config.TenantID})
 	}
 	if d.Config.RegionName != "" {
-		envs = append(envs, corev1.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_REGION", Value: d.Config.RegionName})
+		envs = append(envs, envvar.EnvVar{Name: "REGISTRY_STORAGE_SWIFT_REGION", Value: d.Config.RegionName})
 	}
 
 	return
@@ -340,17 +347,12 @@ func (d *driver) ensureAuthURLHasAPIVersion() error {
 }
 
 func (d *driver) containerExists(client *gophercloud.ServiceClient, containerName string) error {
-	if len(containerName) == 0 {
-		return nil
-	}
 	_, err := containers.Get(client, containerName, containers.GetOpts{}).Extract()
-
 	return err
-
 }
 
 func (d *driver) StorageExists(cr *imageregistryv1.Config) (bool, error) {
-	client, err := d.getSwiftClient(cr)
+	client, err := d.getSwiftClient()
 	if err != nil {
 		util.UpdateCondition(cr, defaults.StorageExists, operatorapi.ConditionUnknown, "Could not connect to registry storage", err.Error())
 		return false, err
@@ -380,7 +382,7 @@ func (d *driver) StorageChanged(cr *imageregistryv1.Config) bool {
 }
 
 func (d *driver) CreateStorage(cr *imageregistryv1.Config) error {
-	client, err := d.getSwiftClient(cr)
+	client, err := d.getSwiftClient()
 	if err != nil {
 		util.UpdateCondition(cr, defaults.StorageExists, operatorapi.ConditionFalse, err.Error(), err.Error())
 		return err
@@ -458,7 +460,7 @@ func (d *driver) RemoveStorage(cr *imageregistryv1.Config) (bool, error) {
 		return false, nil
 	}
 
-	client, err := d.getSwiftClient(cr)
+	client, err := d.getSwiftClient()
 	if err != nil {
 		return false, err
 	}
@@ -487,6 +489,10 @@ func (d *driver) Volumes() ([]corev1.Volume, []corev1.VolumeMount, error) {
 	return nil, nil, nil
 }
 
+func (d *driver) VolumeSecrets() (map[string]string, error) {
+	return nil, nil
+}
+
 // ID return the underlying storage identificator, on this case the Swift
 // container name.
 func (d *driver) ID() string {
